@@ -27,8 +27,8 @@ class CControllerIconMapEdit extends CController {
 
 	protected function checkInput() {
 		$fields = [
-			'iconmapid'      => 'db icon_map.iconmapid',
-			'iconmap'        => 'array'
+			'iconmapid' => 'db icon_map.iconmapid',
+			'iconmap'   => 'array'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -45,44 +45,23 @@ class CControllerIconMapEdit extends CController {
 			return false;
 		}
 
-		$this->inventory_list = [];
-		$inventory_list = getHostInventories();
-		foreach ($inventory_list as $field) {
-			$this->inventory_list[$field['nr']] = $field['title'];
-		}
-
-		$this->images = [];
-		$images = API::Image()->get([
-			'output' => ['imageid', 'name'],
-			'filter' => ['imagetype' => IMAGE_TYPE_ICON]
-		]);
-
-		order_result($images, 'name');
-
-		foreach ($images as $icon) {
-			$this->images[$icon['imageid']] = $icon['name'];
-		}
-
-		reset($this->images);
-		$this->default_imageid = key($this->images);
-
 		if ($this->hasInput('iconmapid')) {
 			$iconmaps = API::IconMap()->get([
 				'output' => ['iconmapid', 'name', 'default_iconid'],
 				'selectMappings' => ['inventory_link', 'expression', 'iconid', 'sortorder'],
-				'iconmapids' => (array) $this->getInput('iconmapid')
+				'iconmapids' => $this->getInput('iconmapid')
 			]);
 
 			if (!$iconmaps) {
 				return false;
 			}
 
-			$this->iconmap = $this->getInput('iconmap', []) + reset($iconmaps);
+			$this->iconmap = $this->getInput('iconmap', []) + $iconmaps[0];
 		}
 		else {
 			$this->iconmap = $this->getInput('iconmap', []) + [
 				'name' => '',
-				'default_iconid' => $this->default_imageid,
+				'default_iconid' => 0,
 				'mappings' => []
 			];
 		}
@@ -93,15 +72,28 @@ class CControllerIconMapEdit extends CController {
 	protected function doAction() {
 		order_result($this->iconmap['mappings'], 'sortorder');
 
+		$images = API::Image()->get([
+			'output' => ['imageid', 'name'],
+			'filter' => ['imagetype' => IMAGE_TYPE_ICON]
+		]);
+
+		order_result($images, 'name');
+		$images = array_column($images, 'name', 'imageid');
+
+		$default_imageid = key($images);
+
+		if (!$this->hasInput('iconmapid')) {
+			$this->iconmap['default_iconid'] = $default_imageid;
+		}
+
 		$data = [
 			'iconmapid' => $this->getInput('iconmapid', 0),
-			'icon_list' => $this->images,
+			'icon_list' => $images,
 			'iconmap' => $this->iconmap,
-			'inventory_list' => $this->inventory_list
+			'inventory_list' => array_column(getHostInventories(), 'title', 'nr'),
+			'default_imageid' => $default_imageid
 		];
 
-		$data['default_imageid'] = $this->default_imageid;
-
 		$response = new CControllerResponseData($data);
 		$response->setTitle(_('Configuration of icon mapping'));
 
