@@ -34,20 +34,20 @@ class CControllerPopupAcknowledgeEdit extends CController {
 			'severity' =>				'ge '.TRIGGER_SEVERITY_NOT_CLASSIFIED.'|le '.TRIGGER_SEVERITY_COUNT,
 			'acknowledge_problem' =>	'db acknowledges.action|in '.ZBX_PROBLEM_UPDATE_NONE.','.ZBX_PROBLEM_UPDATE_ACKNOWLEDGE,
 			'unacknowledge_problem' =>	'db acknowledges.action|in '.ZBX_PROBLEM_UPDATE_NONE.','.ZBX_PROBLEM_UPDATE_UNACKNOWLEDGE,
-			'close_problem' =>			'db acknowledges.action|in '.ZBX_PROBLEM_UPDATE_NONE.','.ZBX_PROBLEM_UPDATE_CLOSE
+			'close_problem' =>			'db acknowledges.action|in '.ZBX_PROBLEM_UPDATE_NONE.','.ZBX_PROBLEM_UPDATE_CLOSE,
+			'suppress_problem' =>		'db acknowledges.action|in '.ZBX_PROBLEM_UPDATE_NONE.','.ZBX_PROBLEM_UPDATE_SUPPRESS,
+			'unsuppress_problem' =>		'db acknowledges.action|in '.ZBX_PROBLEM_UPDATE_NONE.','.ZBX_PROBLEM_UPDATE_UNSUPPRESS
 		];
 
 		$ret = $this->validateInput($fields);
 
 		if (!$ret) {
-			$output = [];
-
-			if (($messages = getMessages()) !== null) {
-				$output['errors'] = $messages->toString();
-			}
-
 			$this->setResponse(
-				(new CControllerResponseData(['main_block' => json_encode($output)]))->disableView()
+				(new CControllerResponseData(['main_block' => json_encode([
+					'error' => [
+						'messages' => array_column(get_and_clear_messages(), 'message')
+					]
+				])]))->disableView()
 			);
 		}
 
@@ -58,7 +58,8 @@ class CControllerPopupAcknowledgeEdit extends CController {
 		if (!$this->checkAccess(CRoleHelper::ACTIONS_ACKNOWLEDGE_PROBLEMS)
 				&& !$this->checkAccess(CRoleHelper::ACTIONS_CLOSE_PROBLEMS)
 				&& !$this->checkAccess(CRoleHelper::ACTIONS_CHANGE_SEVERITY)
-				&& !$this->checkAccess(CRoleHelper::ACTIONS_ADD_PROBLEM_COMMENTS)) {
+				&& !$this->checkAccess(CRoleHelper::ACTIONS_ADD_PROBLEM_COMMENTS)
+				&& !$this->checkAccess(CRoleHelper::ACTIONS_SUPPRESS_PROBLEMS)) {
 			return false;
 		}
 
@@ -83,19 +84,30 @@ class CControllerPopupAcknowledgeEdit extends CController {
 			'acknowledge_problem' => $this->getInput('acknowledge_problem', ZBX_PROBLEM_UPDATE_NONE),
 			'unacknowledge_problem' => $this->getInput('unacknowledge_problem', ZBX_PROBLEM_UPDATE_NONE),
 			'close_problem' => $this->getInput('close_problem', ZBX_PROBLEM_UPDATE_NONE),
+			'suppress_problem' => $this->getInput('suppress_problem', ZBX_PROBLEM_UPDATE_NONE),
+			'unsuppress_problem' => $this->getInput('unsuppress_problem', ZBX_PROBLEM_UPDATE_NONE),
 			'related_problems_count' => 0,
 			'problem_can_be_closed' => false,
+			'problem_can_be_suppressed' => false,
+			'problem_can_be_unsuppressed' => false,
 			'problem_severity_can_be_changed' => false,
 			'allowed_acknowledge' => $this->checkAccess(CRoleHelper::ACTIONS_ACKNOWLEDGE_PROBLEMS),
 			'allowed_close' => $this->checkAccess(CRoleHelper::ACTIONS_CLOSE_PROBLEMS),
 			'allowed_change_severity' => $this->checkAccess(CRoleHelper::ACTIONS_CHANGE_SEVERITY),
-			'allowed_add_comments' => $this->checkAccess(CRoleHelper::ACTIONS_ADD_PROBLEM_COMMENTS)
+			'allowed_add_comments' => $this->checkAccess(CRoleHelper::ACTIONS_ADD_PROBLEM_COMMENTS),
+			'allowed_suppress' => $this->checkAccess(CRoleHelper::ACTIONS_SUPPRESS_PROBLEMS),
+			'suppress_until_problem' => CProfile::get('web.problem_suppress_action_time_until', 'now+1d')
 		];
 
 		// Select events.
 		$events = API::Event()->get([
 			'output' => ['eventid', 'name', 'objectid', 'acknowledged', 'value', 'r_eventid'],
-			'select_acknowledges' => ['userid', 'clock', 'message', 'action', 'old_severity', 'new_severity'],
+			'select_acknowledges' => ['userid', 'clock', 'message', 'action', 'old_severity', 'new_severity',
+				'suppress_until'
+			],
+			'selectSuppressionData' => $this->checkAccess(CRoleHelper::ACTIONS_SUPPRESS_PROBLEMS)
+				? ['maintenanceid', 'suppress_until']
+				: null,
 			'eventids' => $this->getInput('eventids'),
 			'source' => EVENT_SOURCE_TRIGGERS,
 			'object' => EVENT_OBJECT_TRIGGER,
@@ -131,10 +143,23 @@ class CControllerPopupAcknowledgeEdit extends CController {
 		// Loop through events to figure out what operations should be allowed.
 		foreach ($events as $event) {
 			$can_be_closed = true;
+			$can_be_suppressed = true;
+			$can_be_unsuppressed = false;
 
-			// Problems already resolved are not allowed to be closed.
+			// Only manually suppressed problems can be unsuppressed.
+			if ($this->checkAccess(CRoleHelper::ACTIONS_SUPPRESS_PROBLEMS)) {
+				foreach ($event['suppression_data'] as $suppression) {
+					if ($suppression['maintenanceid'] == 0) {
+						$can_be_unsuppressed = true;
+					}
+				}
+			}
+
+			// Problems already resolved are not allowed to be closed, suppressed or unsuppressed.
 			if ($event['r_eventid'] != 0 || $event['value'] == TRIGGER_VALUE_FALSE) {
 				$can_be_closed = false;
+				$can_be_suppressed = false;
+				$can_be_unsuppressed = false;
 				$data['related_problems_count']++; // Count selected but closed events.
 			}
 			// Not allowed to close events generated by non-writable and non-closable triggers.
@@ -143,13 +168,8 @@ class CControllerPopupAcknowledgeEdit extends CController {
 				$can_be_closed = false;
 			}
 			// Look if problem is not currently in closing state due acknowledge actions.
-			elseif ($event['acknowledges']) {
-				foreach ($event['acknowledges'] as $acknowledge) {
-					if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
-						$can_be_closed = false;
-						break;
-					}
-				}
+			elseif (hasEventCloseAction($event['acknowledges'])) {
+				$can_be_closed = false;
 			}
 
 			// If at least one event can be closed, enable 'Close problem' checkbox.
@@ -157,6 +177,16 @@ class CControllerPopupAcknowledgeEdit extends CController {
 				$data['problem_can_be_closed'] = true;
 			}
 
+			// If at least one event can be suppressed, enable 'Suppress' checkbox.
+			if ($can_be_suppressed) {
+				$data['problem_can_be_suppressed'] = true;
+			}
+
+			// If at least one event can be unsuppressed, enable 'Unsuppress' checkbox.
+			if ($can_be_unsuppressed) {
+				$data['problem_can_be_unsuppressed'] = true;
+			}
+
 			$ack_count += ($event['acknowledged'] == EVENT_ACKNOWLEDGED) ? 1 : 0;
 		}
 
