@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -59,12 +59,12 @@ class CControllerUsergroupGrouprightAdd extends CController {
 			'include_subgroups' => '0'
 		];
 
-		list($groupids, $subgroupids) = $new_group_right['include_subgroups']
+		[$groupids, $subgroupids] = $new_group_right['include_subgroups']
 			? [[], $new_group_right['groupids']]
 			: [$new_group_right['groupids'], []];
 
 		$this->setResponse(new CControllerResponseData([
-			'group_rights' => collapseHostGroupRights(applyHostGroupRights(
+			'group_rights' => collapseGroupRights(applyHostGroupRights(
 				$this->getInput('group_rights'), $groupids, $subgroupids, $new_group_right['permission']
 			)),
 			'user' => [
