@@ -29,10 +29,11 @@ $this->includeJsFile('administration.trigdisplay.edit.js.php');
 
 $widget = (new CWidget())
 	->setTitle(_('Trigger displaying options'))
-	->setTitleSubmenu(getAdministrationGeneralSubmenu());
+	->setTitleSubmenu(getAdministrationGeneralSubmenu())
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::ADMINISTRATION_TRIGDISPLAY_EDIT));
 
 $form_list = (new CFormList())
-	->addRow(_('Use custom event status colours'), (new CCheckBox('custom_color'))
+	->addRow(_('Use custom event status colors'), (new CCheckBox('custom_color'))
 		->setUncheckedValue(EVENT_CUSTOM_COLOR_DISABLED)
 		->setChecked($data['custom_color'] == EVENT_CUSTOM_COLOR_ENABLED)
 		->setAttribute('autofocus', 'autofocus')
