@@ -29,7 +29,7 @@ window.host_edit_popup = {
 	dialogue: null,
 	form: null,
 
-	init({popup_url, form_name, host_interfaces, host_is_discovered}) {
+	init({popup_url, form_name, host_interfaces, host_is_discovered, warning}) {
 		this.overlay = overlays_stack.getById('host_edit');
 		this.dialogue = this.overlay.$dialogue[0];
 		this.form = this.overlay.$dialogue.$body[0].querySelector('form');
@@ -37,6 +37,12 @@ window.host_edit_popup = {
 		history.replaceState({}, '', popup_url);
 
 		host_edit.init({form_name, host_interfaces, host_is_discovered});
+
+		if (warning !== null) {
+			const message_box = makeMessageBox('warning', warning, null, true, false)[0];
+
+			this.form.parentNode.insertBefore(message_box, this.form);
+		}
 	},
 
 	submit() {
