@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,10 +21,14 @@
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
 $output = [
-	'body' => (new CPartial('monitoring.latest.view.html', $data))->getOutput()
+	'body' => (new CPartial('monitoring.latest.view.html', $data['results']))->getOutput(),
+	'subfilter' => (new CPartial('monitoring.latest.subfilter',
+		array_intersect_key($data, array_flip(['subfilters', 'subfilters_expanded']))
+	))->getOutput()
 ];
 
 if (($messages = getMessages()) !== null) {
