@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,8 +21,11 @@
 
 /**
  * @var CView $this
+ * @var array $data
  */
 
+$this->includeJsFile('search.js.php');
+
 $widgets = [];
 
 $table = (new CTableInfo())
@@ -44,14 +47,15 @@ $table = (new CTableInfo())
 
 foreach ($data['hosts'] as $hostid => $host) {
 	$interface = reset($host['interfaces']);
-	$link = 'hostid='.$hostid;
 	$visible_name = make_decoration($host['name'], $data['search']);
 
 	$name_link = ($host['editable'] && $data['allowed_ui_conf_hosts'])
-		? new CLink($visible_name, (new CUrl('hosts.php'))
-			->setArgument('form', 'update')
+		? (new CLink($visible_name, (new CUrl('zabbix.php'))
+			->setArgument('action', 'host.edit')
 			->setArgument('hostid', $hostid)
-		)
+		))
+			->setAttribute('data-hostid', $host['hostid'])
+			->onClick('view.editHost(event, this.dataset.hostid);')
 		: new CSpan($visible_name);
 
 	if ($host['status'] == HOST_STATUS_NOT_MONITORED) {
@@ -69,8 +73,8 @@ foreach ($data['hosts'] as $hostid => $host) {
 		? new CLink(_('Latest data'),
 			(new CUrl('zabbix.php'))
 				->setArgument('action', 'latest.view')
-				->setArgument('filter_hostids[]', $hostid)
-				->setArgument('filter_set', '1')
+				->setArgument('hostids[]', $hostid)
+				->setArgument('filter_name', '')
 		)
 		: _('Latest data');
 
@@ -89,8 +93,7 @@ foreach ($data['hosts'] as $hostid => $host) {
 		? new CLink(_('Graphs'),
 			(new CUrl('zabbix.php'))
 				->setArgument('action', 'charts.view')
-				->setArgument('view_as', HISTORY_GRAPH)
-				->setArgument('filter_hostids[]', $hostid)
+				->setArgument('filter_hostids', (array) $hostid)
 				->setArgument('filter_set', '1')
 		)
 		: _('Graphs');
@@ -188,56 +191,54 @@ $table = (new CTableInfo())
 	->setHeader((new CRowHeader())
 		->addItem(new CColHeader(_('Host group')))
 		->addItem((new CColHeader(_('Monitoring')))
-			->setColSpan($data['groups'] ? 3 : 1)
+			->setColSpan($data['host_groups'] ? 3 : 1)
 			->addClass(ZBX_STYLE_TABLE_LEFT_BORDER)
 		)
-		->addItem($data['admin']
-			? (new CColHeader(_('Configuration')))
-				->setColSpan($data['groups'] ? 2 : 1)
-				->addClass(ZBX_STYLE_TABLE_LEFT_BORDER)
-			: null
+		->addItem(
+			$data['admin']
+				? (new CColHeader(_('Configuration')))->addClass(ZBX_STYLE_TABLE_LEFT_BORDER)
+				: null
 		)
 	);
 
-foreach ($data['groups'] as $groupid => $group) {
+foreach ($data['host_groups'] as $groupid => $group) {
 	$caption = make_decoration($group['name'], $data['search']);
-	$link = 'groupid='.$groupid.'&hostid=0';
+	$name_link = $group['editable'] && $data['allowed_ui_conf_host_groups']
+		? (new CLink($caption, (new CUrl('zabbix.php'))
+			->setArgument('action', 'hostgroup.edit')
+			->setArgument('groupid', $groupid)
+		))
+			->addClass('js-edit-hostgroup')
+			->setAttribute('data-groupid', $groupid)
+		: new CSpan($caption);
+
 	$hosts_link = null;
-	$templates_link = null;
 
 	if ($data['admin']) {
 		$hosts_link = ($group['editable'] && $data['allowed_ui_conf_hosts'] && $group['hosts'])
-			? [new CLink(_('Hosts'), (new CUrl('hosts.php'))
+			? [new CLink(_('Hosts'), (new CUrl('zabbix.php'))
+				->setArgument('action', 'host.list')
 				->setArgument('filter_set', '1')
 				->setArgument('filter_groups', [$groupid])
 			), CViewHelper::showNum($group['hosts'])]
 			: _('Hosts');
 
 		$hosts_link = (new CCol($hosts_link))->addClass(ZBX_STYLE_TABLE_LEFT_BORDER);
-
-		$templates_link = ($group['editable'] && $data['allowed_ui_conf_templates'] && $group['templates'])
-			? [new CLink(_('Templates'), (new CUrl('templates.php'))
-				->setArgument('filter_set', '1')
-				->setArgument('filter_groups', [$groupid])
-			), CViewHelper::showNum($group['templates'])]
-			: _('Templates');
 	}
 
 	$latest_data_link = $data['allowed_ui_latest_data']
 		? new CLink(_('Latest data'),
 			(new CUrl('zabbix.php'))
 				->setArgument('action', 'latest.view')
-				->setArgument('filter_groupids[]', $groupid)
-				->setArgument('filter_set', '1')
+				->setArgument('groupids[]', $groupid)
+				->setArgument('filter_name', '')
 		)
 		: _('Latest data');
 
 	$latest_data_link = (new CCol($latest_data_link))->addClass(ZBX_STYLE_TABLE_LEFT_BORDER);
 
 	$table->addRow([
-		$group['editable'] && $data['allowed_ui_conf_host_groups']
-			? new CLink($caption, 'hostgroups.php?form=update&'.$link)
-			: new CSpan($caption),
+		$name_link,
 		$latest_data_link,
 		$data['allowed_ui_problems']
 			? new CLink(_('Problems'),
@@ -255,8 +256,7 @@ foreach ($data['groups'] as $groupid => $group) {
 					->setArgument('filter_set', '1')
 			)
 			:_('Web'),
-		$hosts_link,
-		$templates_link
+		$hosts_link
 	]);
 }
 
@@ -265,7 +265,7 @@ $widgets[] = (new CCollapsibleUiWidget(WIDGET_SEARCH_HOSTGROUP, $table))
 	->setExpanded((bool) CProfile::get('web.search.hats.'.WIDGET_SEARCH_HOSTGROUP.'.state', true))
 	->setHeader(_('Host groups'), [], 'web.search.hats.'.WIDGET_SEARCH_HOSTGROUP.'.state')
 	->setFooter(new CList([
-		_s('Displaying %1$s of %2$s found', count($data['groups']), $data['total_groups_cnt'])
+		_s('Displaying %1$s of %2$s found', count($data['host_groups']), $data['total_host_groups_cnt'])
 	]));
 
 if ($data['admin']) {
@@ -368,7 +368,56 @@ if ($data['admin']) {
 		]));
 }
 
+$table = (new CTableInfo())
+	->setHeader((new CRowHeader())
+		->addItem(new CColHeader(_('Template group')))
+		->addItem(
+			$data['admin']
+				? (new CColHeader(_('Configuration')))->addClass(ZBX_STYLE_TABLE_LEFT_BORDER)
+				: null
+		)
+	);
+
+foreach ($data['template_groups'] as $groupid => $group) {
+	$caption = make_decoration($group['name'], $data['search']);
+	$name_link = $group['editable'] && $data['allowed_ui_conf_template_groups']
+		? (new CLink($caption, (new CUrl('zabbix.php'))
+			->setArgument('action', 'templategroup.edit')
+			->setArgument('groupid', $groupid)
+		))
+			->addClass('js-edit-templategroup')
+			->setAttribute('data-groupid', $groupid)
+		: new CSpan($caption);
+
+	$templates_link = null;
+
+	if ($data['admin']) {
+		$templates_link = ($group['editable'] && $data['allowed_ui_conf_templates'] && $group['templates'])
+			? [new CLink(_('Templates'), (new CUrl('templates.php'))
+				->setArgument('filter_set', '1')
+				->setArgument('filter_groups', [$groupid])
+			), CViewHelper::showNum($group['templates'])]
+			: _('Templates');
+		$templates_link = (new CCol($templates_link))->addClass(ZBX_STYLE_TABLE_LEFT_BORDER);
+	}
+
+	$table->addRow([$name_link, $templates_link]);
+}
+
+$widgets[] = (new CCollapsibleUiWidget(WIDGET_SEARCH_TEMPLATEGROUP, $table))
+	->addClass(ZBX_STYLE_DASHBOARD_WIDGET_FLUID)
+	->setExpanded((bool) CProfile::get('web.search.hats.'.WIDGET_SEARCH_TEMPLATEGROUP.'.state', true))
+	->setHeader(_('Template groups'), [], 'web.search.hats.'.WIDGET_SEARCH_TEMPLATEGROUP.'.state')
+	->setFooter(new CList([
+		_s('Displaying %1$s of %2$s found', count($data['template_groups']), $data['total_template_groups_cnt'])
+	]));
+
 (new CWidget())
 	->setTitle(_('Search').': '.$data['search'])
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::SEARCH))
 	->addItem(new CDiv($widgets))
 	->show();
+
+(new CScriptTag('view.init();'))
+	->setOnDocumentReady()
+	->show();
