@@ -230,19 +230,29 @@ final class CItemData {
 			'net.tcp.service[service,<ip>,<port>]',
 			'net.udp.service.perf[service,<ip>,<port>]',
 			'net.udp.service[service,<ip>,<port>]',
+			'vmware.alarms.get[<url>]',
 			'vmware.cl.perfcounter[<url>,<id>,<path>,<instance>]',
+			'vmware.cluster.alarms.get[<url>,<id>]',
 			'vmware.cluster.discovery[<url>]',
+			'vmware.cluster.property[<url>,<id>,<prop>]',
 			'vmware.cluster.status[<url>,<name>]',
+			'vmware.cluster.tags.get[<url>,<id>]',
+			'vmware.datastore.alarms.get[<url>,<uuid>]',
 			'vmware.datastore.discovery[<url>]',
 			'vmware.datastore.hv.list[<url>,<datastore>]',
+			'vmware.datastore.property[<url>,<uuid>,<prop>]',
 			'vmware.datastore.read[<url>,<datastore>,<mode>]',
 			'vmware.datastore.size[<url>,<datastore>,<mode>]',
+			'vmware.datastore.tags.get[<url>,<uuid>]',
 			'vmware.datastore.write[<url>,<datastore>,<mode>]',
+			'vmware.dc.alarms.get[<url>,<id>]',
 			'vmware.dc.discovery[<url>]',
+			'vmware.dc.tags.get[<url>,<id>]',
 			'vmware.dvswitch.discovery[<url>]',
 			'vmware.dvswitch.fetchports.get[<url>,<filter>,<mode>]',
 			'vmware.eventlog[<url>,<mode>]',
 			'vmware.fullname[<url>]',
+			'vmware.hv.alarms.get[<url>,<uuid>]',
 			'vmware.hv.cluster.name[<url>,<uuid>]',
 			'vmware.hv.connectionstate[<url>,<uuid>]',
 			'vmware.hv.cpu.usage.perf[<url>,<uuid>]',
@@ -276,15 +286,18 @@ final class CItemData {
 			'vmware.hv.network.out[<url>,<uuid>,<mode>]',
 			'vmware.hv.perfcounter[<url>,<uuid>,<path>,<instance>]',
 			'vmware.hv.power[<url>,<uuid>,<max>]',
+			'vmware.hv.property[<url>,<uuid>,<prop>]',
 			'vmware.hv.sensor.health.state[<url>,<uuid>]',
 			'vmware.hv.sensors.get[<url>,<uuid>]',
 			'vmware.hv.status[<url>,<uuid>]',
+			'vmware.hv.tags.get[<url>,<uuid>]',
 			'vmware.hv.uptime[<url>,<uuid>]',
 			'vmware.hv.version[<url>,<uuid>]',
 			'vmware.hv.vm.num[<url>,<uuid>]',
 			'vmware.rp.cpu.usage[<url>,<rpid>]',
 			'vmware.rp.memory[<url>,<rpid>,<mode>]',
 			'vmware.version[<url>]',
+			'vmware.vm.alarms.get[<url>,<uuid>]',
 			'vmware.vm.attribute[<url>,<uuid>,<name>]',
 			'vmware.vm.cluster.name[<url>,<uuid>]',
 			'vmware.vm.consolidationneeded[<url>,<uuid>]',
@@ -316,6 +329,7 @@ final class CItemData {
 			'vmware.vm.net.if.usage[<url>,<uuid>,<instance>]',
 			'vmware.vm.perfcounter[<url>,<uuid>,<path>,<instance>]',
 			'vmware.vm.powerstate[<url>,<uuid>]',
+			'vmware.vm.property[<url>,<uuid>,<prop>]',
 			'vmware.vm.snapshot.get[<url>,<uuid>]',
 			'vmware.vm.state[<url>,<uuid>]',
 			'vmware.vm.storage.committed[<url>,<uuid>]',
@@ -325,6 +339,7 @@ final class CItemData {
 			'vmware.vm.storage.uncommitted[<url>,<uuid>]',
 			'vmware.vm.storage.unshared[<url>,<uuid>]',
 			'vmware.vm.storage.writeoio[<url>,<uuid>,<instance>]',
+			'vmware.vm.tags.get[<url>,<uuid>]',
 			'vmware.vm.tools[<url>,<uuid>,<mode>]',
 			'vmware.vm.uptime[<url>,<uuid>]',
 			'vmware.vm.vfs.dev.discovery[<url>,<uuid>]',
@@ -1229,18 +1244,38 @@ final class CItemData {
 				'description' => _('Virtual space size in bytes or in percentage from total. Returns integer for bytes; float for percentage'),
 				'value_type' => null
 			],
+			'vmware.alarms.get[<url>]' => [
+				'description' => _('VMware virtual center alarms data, returns JSON, <url> - VMware service URL'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.cl.perfcounter[<url>,<id>,<path>,<instance>]' => [
 				'description' => _('VMware cluster performance counter, <url> - VMware service URL, <id> - VMware cluster id, <path> - performance counter path, <instance> - performance counter instance'),
 				'value_type' => ITEM_VALUE_TYPE_FLOAT
 			],
+			'vmware.cluster.alarms.get[<url>,<id>]' => [
+				'description' => _('VMware cluster alarms data, returns JSON, <url> - VMware service URL, <id> - VMware cluster id'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.cluster.discovery[<url>]' => [
 				'description' => _('Discovery of VMware clusters, <url> - VMware service URL. Returns JSON'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'vmware.cluster.property[<url>,<id>,<prop>]' => [
+				'description' => _('VMware cluster property, <url> - VMware service URL, <id> - VMware cluster id, <prop> - property path'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.cluster.status[<url>,<name>]' => [
 				'description' => _('VMware cluster status, <url> - VMware service URL, <name> - VMware cluster name'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
 			],
+			'vmware.cluster.tags.get[<url>,<id>]' => [
+				'description' => _('VMware cluster tags array, <url> - VMware service URL, <id> - VMware cluster id'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
+			'vmware.datastore.alarms.get[<url>,<uuid>]' => [
+				'description' => _('VMware datastore alarms data, returns JSON, <url> - VMware service URL, <uuid> - VMware datastore name'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.datastore.discovery[<url>]' => [
 				'description' => _('Discovery of VMware datastores, <url> - VMware service URL. Returns JSON'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
@@ -1249,6 +1284,10 @@ final class CItemData {
 				'description' => _('VMware datastore hypervisors list, <url> - VMware service URL, <datastore> - datastore name'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'vmware.datastore.property[<url>,<uuid>,<prop>]' => [
+				'description' => _('VMware datastore property, <url> - VMware service URL, <uuid> - datastore name, <prop> - property path'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.datastore.read[<url>,<datastore>,<mode>]' => [
 				'description' => _('VMware datastore read statistics, <url> - VMware service URL, <datastore> - datastore name, <mode> - latency/maxlatency - average or maximum'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
@@ -1257,14 +1296,26 @@ final class CItemData {
 				'description' => _('VMware datastore capacity statistics in bytes or in percentage from total. Returns integer for bytes; float for percentage'),
 				'value_type' => null
 			],
+			'vmware.datastore.tags.get[<url>,<uuid>]' => [
+				'description' => _('VMware datastore tags array, <url> - VMware service URL, <uuid> - VMware datastore uuid. Returns JSON'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.datastore.write[<url>,<datastore>,<mode>]' => [
 				'description' => _('VMware datastore write statistics, <url> - VMware service URL, <datastore> - datastore name, <mode> - latency/maxlatency - average or maximum'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'vmware.dc.alarms.get[<url>,<id>]' => [
+				'description' => _('VMware datacenter alarms data, returns JSON, <url> - VMware service URL, <id> - VMware datacenter id'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.dc.discovery[<url>]' => [
 				'description' => _('VMware datacenters and their IDs, <url> - VMware service URL. Returns JSON'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
 			],
+			'vmware.dc.tags.get[<url>,<id>]' => [
+				'description' => _('VMware datacenter tags array, <url> - VMware service URL, <id> - VMware datacenter id. Returns JSON'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.dvswitch.discovery[<url>]' => [
 				'description' => _('VMware Distributed Virtual Switch, <url> - VMware service URL. Returns JSON'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
@@ -1281,6 +1332,10 @@ final class CItemData {
 				'description' => _('VMware service full name, <url> - VMware service URL'),
 				'value_type' => ITEM_VALUE_TYPE_STR
 			],
+			'vmware.hv.alarms.get[<url>,<uuid>]' => [
+				'description' => _('VMware hypervisor alarms data, returns JSON, <url> - VMware service URL, <uuid> - VMware hypervisor host name'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.hv.cluster.name[<url>,<uuid>]' => [
 				'description' => _('VMware hypervisor cluster name, <url> - VMware service URL, <uuid> - VMware hypervisor host name'),
 				'value_type' => ITEM_VALUE_TYPE_STR
@@ -1413,6 +1468,10 @@ final class CItemData {
 				'description' => _('Power usage , <url> - VMware service URL, <uuid> - VMware hypervisor host name, <max> - Maximum allowed power usage'),
 				'value_type' => ITEM_VALUE_TYPE_FLOAT
 			],
+			'vmware.hv.property[<url>,<uuid>,<prop>]' => [
+				'description' => _('VMware hypervisor property , <url> - VMware service URL, <uuid> - VMware hypervisor host name, <prop> - property path'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.hv.sensor.health.state[<url>,<uuid>]' => [
 				'description' => _('VMware hypervisor health state rollup sensor, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns 0 - gray; 1 - green; 2 - yellow; 3 - red'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
@@ -1425,6 +1484,10 @@ final class CItemData {
 				'description' => _('VMware hypervisor status, <url> - VMware service URL, <uuid> - VMware hypervisor host name'),
 				'value_type' => null
 			],
+			'vmware.hv.tags.get[<url>,<uuid>]' => [
+				'description' => _('VMware hypervisor tags array, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns JSON'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.hv.uptime[<url>,<uuid>]' => [
 				'description' => _('VMware hypervisor uptime, <url> - VMware service URL, <uuid> - VMware hypervisor host name'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
@@ -1449,6 +1512,10 @@ final class CItemData {
 				'description' => _('VMware service version, <url> - VMware service URL'),
 				'value_type' => ITEM_VALUE_TYPE_STR
 			],
+			'vmware.vm.alarms.get[<url>,<uuid>]' => [
+				'description' => _('VMware virtual machine alarms data, returns JSON, <url> - VMware service URL, <uuid> - VMware virtual machine name'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.vm.attribute[<url>,<uuid>,<name>]' => [
 				'description' => _('VMware virtual machine custom attribute value, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <name> - custom attribute name'),
 				'value_type' => ITEM_VALUE_TYPE_STR
@@ -1573,6 +1640,10 @@ final class CItemData {
 				'description' => _('VMware virtual machine power state, <url> - VMware service URL, <uuid> - VMware virtual machine host name'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
 			],
+			'vmware.vm.property[<url>,<uuid>,<prop>]' => [
+				'description' => _('VMware virtual machine property, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <prop> - property path'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.vm.snapshot.get[<url>,<uuid>]' => [
 				'description' => _('VMware virtual machine snapshot state, <url> - VMware service URL, <uuid> - VMware virtual machine host name. Returns JSON'),
 				'value_type' => ITEM_VALUE_TYPE_TEXT
@@ -1609,6 +1680,10 @@ final class CItemData {
 				'description' => _('Average number of outstanding write requests to the virtual disk during the collection interval, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - disk device instance'),
 				'value_type' => ITEM_VALUE_TYPE_UINT64
 			],
+			'vmware.vm.tags.get[<url>,<uuid>]' => [
+				'description' => _('VMware virtual machine tags array, <url> - VMware service URL, <uuid> - VMware virtual machine host name. Returns JSON'),
+				'value_type' => ITEM_VALUE_TYPE_TEXT
+			],
 			'vmware.vm.tools[<url>,<uuid>,<mode>]' => [
 				'description' => _('VMware virtual machine tools state, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <mode> - version or status'),
 				'value_type' => ITEM_VALUE_TYPE_STR
