@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,25 +23,12 @@ class CClock extends CDiv {
 
 	private $width;
 	private $height;
-	private $time_zone_string;
-	private $time;
-	private $time_zone_offset;
-	private $error;
-	private $script_file;
+	private $is_enabled = true;
 
 	public function __construct() {
 		parent::__construct();
 
-		$this->setId(uniqid());
 		$this->addClass(ZBX_STYLE_CLOCK);
-
-		$this->width = null;
-		$this->height = null;
-		$this->time_zone_string = null;
-		$this->time = null;
-		$this->time_zone_offset = null;
-		$this->error = null;
-		$this->script_file = 'js/class.cclock.js';
 	}
 
 	public function setWidth($value) {
@@ -56,59 +43,12 @@ class CClock extends CDiv {
 		return $this;
 	}
 
-	public function setTimeZoneString($value) {
-		$this->time_zone_string = $value;
+	public function setEnabled($is_enabled) {
+		$this->is_enabled = $is_enabled;
 
 		return $this;
 	}
 
-	public function setTime($value) {
-		$this->time = $value;
-
-		return $this;
-	}
-
-	public function setTimeZoneOffset($value) {
-		$this->time_zone_offset = $value;
-
-		return $this;
-	}
-
-	public function setError($value) {
-		$this->error = $value;
-
-		return $this;
-	}
-
-	public function getTimeDiv() {
-		return (new CDiv($this->error))
-			->addClass(ZBX_STYLE_TIME_ZONE.'-'.$this->getId())
-			->addClass($this->error !== null ? ZBX_STYLE_RED : ZBX_STYLE_GREY);
-	}
-
-	public function getScriptFile() {
-		return $this->script_file;
-	}
-
-	public function getScriptRun() {
-		return ($this->error === null)
-			? 'jQuery(function($) {'.
-				'$("#'.$this->getId().'").zbx_clock('.
-					CJs::encodeJson([
-						'time' => $this->time,
-						'time_zone_string' => $this->time_zone_string,
-						'time_zone_offset' => $this->time_zone_offset,
-						'clock_id' => $this->getId()
-					]).
-				');'.
-				// Hack for Safari to manually accept parent container height in pixels when clock widget is loaded.
-				'if (SF) {'.
-					'$("#'.$this->getId().'").height($("#'.$this->getId().'").parent().height());'.
-				'}'.
-			'});'
-			: '';
-	}
-
 	private function makeClockLine($width, $height, $x, $y, $deg) {
 		return (new CTag('rect', true))
 			->setAttribute('width', $width)
@@ -185,12 +125,10 @@ class CClock extends CDiv {
 			->addClass(ZBX_STYLE_CLOCK_SVG);
 
 		if ($this->width !== null && $this->height !== null) {
-			$clock
-				->setAttribute('width', (string) $this->width.'px')
-				->setAttribute('height', (string) $this->height.'px');
+			$clock->setAttribute('style', 'width: '.$this->width.'px; height:'.$this->height.'px;');
 		}
 
-		if ($this->error !== null) {
+		if (!$this->is_enabled) {
 			$clock->addClass(ZBX_STYLE_DISABLED);
 		}
 
