@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,12 +38,13 @@ class CCollapsibleUiWidget extends CUiWidget {
 	/**
 	 * Sets the header and adds a default expand-collapse icon.
 	 *
-	 * @param string $caption      Header caption.
-	 * @param array  $controls     (optional)
-	 * @param bool   $cursor_move  (optional)
-	 * @param string $idx          (optional)
+	 * @param string $caption   Header caption.
+	 * @param array  $controls  (optional)
+	 * @param string $idx       (optional)
+	 *
+	 * @return $this
 	 */
-	public function setHeader($caption, array $controls = [], $cursor_move = false, $idx = '') {
+	public function setHeader($caption, array $controls = [], $idx = '') {
 		$icon = (new CRedirectButton(null, null))
 			->setId($this->id.'_icon')
 			->onClick('changeWidgetState(this, "'.$this->id.'", "'.$idx.'");');
@@ -61,7 +62,7 @@ class CCollapsibleUiWidget extends CUiWidget {
 
 		$controls[] = $icon;
 
-		parent::setHeader($caption, $controls, $cursor_move);
+		parent::setHeader($caption, $controls);
 
 		return $this;
 	}
