@@ -1,7 +1,7 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -579,7 +579,7 @@ class C52ImportConverter extends CConverter {
 		$expression_converter = new C52TriggerExpressionConverter();
 		$event_name_converter = new C52EventNameConverter();
 
-		$expression_parser = new CExpressionParser();
+		$expression_parser = new CExpressionParser(['usermacros' => true]);
 
 		foreach ($triggers as &$trigger) {
 			$trigger['expression'] = $expression_converter->convert([
