@@ -213,7 +213,7 @@ function addElementNames(array &$selements) {
 	$groups = $groupids
 		? API::HostGroup()->get([
 			'output' => ['name'],
-			'hostgroupids' => $groupids,
+			'groupids' => $groupids,
 			'preservekeys' => true
 		])
 		: [];
@@ -294,12 +294,13 @@ function addElementNames(array &$selements) {
  *                                           SYSMAP_SINGLE_PROBLEM, SYSMAP_PROBLEMS_NUMBER,
  *                                           SYSMAP_PROBLEMS_NUMBER_CRITICAL.
  * @param string   $i['problem_title']       (optional) The name of the most critical problem.
+ * @param int      $host_count               (optional) Number of unique hosts that the current selement is related to.
  * @param int|null $show_unack               (optional) Map "Problem display" option. Possible values:
  *                                           EXTACK_OPTION_ALL, EXTACK_OPTION_UNACK, EXTACK_OPTION_BOTH.
  *
  * @return array
  */
-function getSelementInfo(array $i, ?int $show_unack = null): array {
+function getSelementInfo(array $i, int $host_count = 0, int $show_unack = null): array {
 	if ($i['elementtype'] == SYSMAP_ELEMENT_TYPE_IMAGE) {
 		return [
 			'iconid' => $i['iconid_off'],
@@ -401,9 +402,14 @@ function getSelementInfo(array $i, ?int $show_unack = null): array {
 			: $i['problem_title'];
 	}
 
+	$all_hosts_in_maintenance = $i['maintenance'] && ($host_count == $i['disabled'] + $i['maintenance']);
+
 	if ($i['maintenance']) {
-		$info['iconid'] = $i['iconid_maintenance'];
-		$info['icon_type'] = SYSMAP_ELEMENT_ICON_MAINTENANCE;
+		if (!$has_problem && $all_hosts_in_maintenance) {
+			$info['iconid'] = $i['iconid_maintenance'];
+			$info['icon_type'] = SYSMAP_ELEMENT_ICON_MAINTENANCE;
+		}
+
 		$info['info']['maintenance'] = [
 			'msg' => ($i['elementtype'] == SYSMAP_ELEMENT_TYPE_HOST)
 				? _('In maintenance')
@@ -413,7 +419,7 @@ function getSelementInfo(array $i, ?int $show_unack = null): array {
 	}
 
 	if (!$has_problem) {
-		if (!$i['maintenance']) {
+		if (!$all_hosts_in_maintenance) {
 			$info['iconid'] = $i['iconid_off'];
 			$info['icon_type'] = SYSMAP_ELEMENT_ICON_OFF;
 		}
@@ -565,13 +571,13 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 	if ($hostGroupIdToSelementIds) {
 		$hostsFromHostGroups = API::Host()->get([
 			'output' => ['name', 'status', 'maintenance_status'],
-			'selectGroups' => ['groupid'],
+			'selectHostGroups' => ['groupid'],
 			'groupids' => array_keys($hostGroupIdToSelementIds),
 			'preservekeys' => true
 		]);
 
 		foreach ($hostsFromHostGroups as $hostId => $host) {
-			foreach ($host['groups'] as $group) {
+			foreach ($host['hostgroups'] as $group) {
 				$groupId = $group['groupid'];
 
 				if (isset($hostGroupIdToSelementIds[$groupId])) {
@@ -612,7 +618,7 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 
 		$triggers = API::Trigger()->get([
 			'output' => ['triggerid', 'status', 'value', 'priority', 'description', 'expression'],
-			'selectHosts' => ['hostid', 'maintenance_status'],
+			'selectHosts' => ['hostid', 'status', 'maintenance_status'],
 			'triggerids' => array_keys($all_triggerid_to_selementids),
 			'filter' => ['state' => null],
 			'preservekeys' => true
@@ -653,7 +659,7 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 	if ($monitored_hostids) {
 		$triggers = API::Trigger()->get([
 			'output' => ['triggerid', 'status', 'value', 'priority', 'description', 'expression'],
-			'selectHosts' => ['hostid', 'maintenance_status'],
+			'selectHosts' => ['hostid', 'status', 'maintenance_status'],
 			'selectItems' => ['itemid'],
 			'hostids' => array_keys($monitored_hostids),
 			'filter' => ['state' => null],
@@ -715,7 +721,7 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 			$filtered_problems = getProblemsMatchingTags($filtered_problems, $selement['tags'], $selement['evaltype']);
 		}
 
-		// Apply filtgered problems to elements they belong to.
+		// Apply filtered problems to elements they belong to.
 		foreach ($filtered_problems as $problem) {
 			$selement['triggers'][$problem['objectid']]['problems'][] = $problem;
 		}
@@ -745,6 +751,8 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 			continue;
 		}
 
+		$host_count = count($selement['hosts']);
+
 		if ($selement['elementtype'] == SYSMAP_ELEMENT_TYPE_TRIGGER
 				|| $selement['elementtype'] == SYSMAP_ELEMENT_TYPE_MAP) {
 			$trigger_hosts = [];
@@ -753,11 +761,13 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 					if (!array_key_exists($host['hostid'], $trigger_hosts)
 							&& !array_key_exists($host['hostid'], $selement['hosts'])) {
 						$trigger_hosts[$host['hostid']] = true;
+						$host_count++;
 
-						if ($host['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON
+						if ($host['status'] == HOST_STATUS_MONITORED
+								&& $host['maintenance_status'] == HOST_MAINTENANCE_STATUS_ON
 								&& ($selement['elementtype'] == SYSMAP_ELEMENT_TYPE_TRIGGER
-								|| ($selement['elementtype'] == SYSMAP_ELEMENT_TYPE_MAP
-									&& array_key_exists(SYSMAP_ELEMENT_TYPE_TRIGGER, $trigger['source'])))) {
+									|| ($selement['elementtype'] == SYSMAP_ELEMENT_TYPE_MAP
+										&& array_key_exists(SYSMAP_ELEMENT_TYPE_TRIGGER, $trigger['source'])))) {
 							$i['maintenance']++;
 						}
 					}
@@ -825,9 +835,9 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 				}
 			}
 
-			$i['latelyChanged'] |= ((time() - $lately_changed) < timeUnitToSeconds(CSettingsHelper::get(
-				CSettingsHelper::BLINK_PERIOD
-			)));
+			if ((time() - $lately_changed) < timeUnitToSeconds(CSettingsHelper::get(CSettingsHelper::BLINK_PERIOD))) {
+				$i['latelyChanged'] = true;
+			}
 		}
 
 		if ($critical_problem) {
@@ -851,7 +861,7 @@ function getSelementsInfo(array $sysmap, array $options = []): array {
 		$i['iconid_maintenance'] = $selement['iconid_maintenance'];
 		$i['iconid_disabled'] = $selement['iconid_disabled'];
 
-		$info[$selementId] = getSelementInfo($i, $sysmap['show_unack']);
+		$info[$selementId] = getSelementInfo($i, $host_count, $sysmap['show_unack']);
 
 		if ($selement['elementtype'] == SYSMAP_ELEMENT_TYPE_HOST && $sysmap['iconmapid'] && $selement['use_iconmap']) {
 			$host_inventory = $host_inventories[$selement['elements'][0]['hostid']];
@@ -1262,7 +1272,7 @@ function getMapHighligts(array $map, array $map_info) {
 
 		switch ($element_info['icon_type']) {
 			case SYSMAP_ELEMENT_ICON_ON:
-				$hl_color = getSeverityColor($element_info['priority']);
+				$hl_color = CSeverityHelper::getColor((int) $element_info['priority']);
 				break;
 
 			case SYSMAP_ELEMENT_ICON_MAINTENANCE:
