@@ -47,10 +47,8 @@ $url = (new CUrl('graphs.php'))
 $graphForm = (new CForm('post', $url))
 	->setName('graphForm')
 	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
-	->addVar('form', $this->data['form'])
-	->addVar('hostid', $this->data['hostid'])
-	->addVar('ymin_itemid', $data['ymin_itemid'])
-	->addVar('ymax_itemid', $data['ymax_itemid']);
+	->addVar('form', $data['form'])
+	->addVar('hostid', $data['hostid']);
 
 if ($data['parent_discoveryid'] !== null) {
 	$graphForm->addItem((new CVar('parent_discoveryid', $data['parent_discoveryid']))->removeId());
@@ -63,7 +61,7 @@ if ($data['graphid'] != 0) {
 // Create form list.
 $graphFormList = new CFormList('graphFormList');
 
-$is_templated = (bool) $this->data['templates'];
+$is_templated = (bool) $data['templates'];
 if ($is_templated) {
 	$graphFormList->addRow(_('Parent graphs'), $data['templates']);
 }
@@ -76,6 +74,7 @@ if (array_key_exists('flags', $data) && $data['flags'] == ZBX_FLAG_DISCOVERY_CRE
 $readonly = false;
 if ($is_templated || $discovered_graph) {
 	$readonly = true;
+	$graphForm->addItem((new CVar('readonly', 1))->removeId());
 }
 
 if ($discovered_graph) {
@@ -91,18 +90,18 @@ if ($discovered_graph) {
 $graphFormList
 	->addRow(
 		(new CLabel(_('Name'), 'name'))->setAsteriskMark(),
-		(new CTextBox('name', $this->data['name'], $readonly))
+		(new CTextBox('name', $data['name'], $readonly))
 			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
 			->setAriaRequired()
 			->setAttribute('autofocus', 'autofocus')
 	)
 	->addRow((new CLabel(_('Width'), 'width'))->setAsteriskMark(),
-		(new CNumericBox('width', $this->data['width'], 5, $readonly))
+		(new CNumericBox('width', $data['width'], 5, $readonly))
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 			->setAriaRequired()
 	)
 	->addRow((new CLabel(_('Height'), 'height'))->setAsteriskMark(),
-		(new CNumericBox('height', $this->data['height'], 5, $readonly))
+		(new CNumericBox('height', $data['height'], 5, $readonly))
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 			->setAriaRequired()
 	)
@@ -110,107 +109,130 @@ $graphFormList
 		(new CSelect('graphtype'))
 			->setId('graphtype')
 			->setFocusableElementId('label-graphtype')
-			->setValue($this->data['graphtype'])
+			->setValue($data['graphtype'])
 			->addOptions(CSelect::createOptionsFromArray(graphType()))
 			->setDisabled($readonly)
 	)
 	->addRow(_('Show legend'),
 		(new CCheckBox('show_legend'))
-			->setChecked($this->data['show_legend'] == 1)
+			->setChecked($data['show_legend'] == 1)
 			->setEnabled(!$readonly)
 	);
 
 // Append graph types to form list.
-if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] == GRAPH_TYPE_STACKED) {
+if ($data['graphtype'] == GRAPH_TYPE_NORMAL || $data['graphtype'] == GRAPH_TYPE_STACKED) {
 	$graphFormList->addRow(_('Show working time'),
 		(new CCheckBox('show_work_period'))
-			->setChecked($this->data['show_work_period'] == 1)
+			->setChecked($data['show_work_period'] == 1)
 			->setEnabled(!$readonly)
 	);
 	$graphFormList->addRow(_('Show triggers'),
 		(new CCheckbox('show_triggers'))
-			->setchecked($this->data['show_triggers'] == 1)
+			->setchecked($data['show_triggers'] == 1)
 			->setEnabled(!$readonly)
 	);
 
-	if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL) {
+	if ($data['graphtype'] == GRAPH_TYPE_NORMAL) {
 		// Percent left.
-		$percentLeftTextBox = (new CTextBox('percent_left', $this->data['percent_left'], $readonly, 7))
+		$percentLeftTextBox = (new CTextBox('percent_left', $data['percent_left'], $readonly, 7))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH);
 		$percentLeftCheckbox = (new CCheckBox('visible[percent_left]'))
 			->setChecked(true)
 			->onClick('showHideVisible("percent_left");')
 			->setEnabled(!$readonly);
 
-		if(isset($this->data['visible']) && isset($this->data['visible']['percent_left'])) {
+		if(array_key_exists('visible', $data) && array_key_exists('percent_left', $data['visible'])) {
 			$percentLeftCheckbox->setChecked(true);
 		}
-		elseif ($this->data['percent_left'] == 0) {
+		elseif ($data['percent_left'] == 0) {
 			$percentLeftTextBox->addStyle('visibility: hidden;');
 			$percentLeftCheckbox->setChecked(false);
 		}
 
-		$graphFormList->addRow(_('Percentile line (left)'), [$percentLeftCheckbox, SPACE, $percentLeftTextBox]);
+		$graphFormList->addRow(_('Percentile line (left)'), [$percentLeftCheckbox, ' ', $percentLeftTextBox]);
 
 		// Percent right.
-		$percentRightTextBox = (new CTextBox('percent_right', $this->data['percent_right'], $readonly, 7))
+		$percentRightTextBox = (new CTextBox('percent_right', $data['percent_right'], $readonly, 7))
 			->setWidth(ZBX_TEXTAREA_TINY_WIDTH);
 		$percentRightCheckbox = (new CCheckBox('visible[percent_right]'))
 			->setChecked(true)
 			->onClick('showHideVisible("percent_right");')
 			->setEnabled(!$readonly);
 
-		if(isset($this->data['visible']) && isset($this->data['visible']['percent_right'])) {
+		if(array_key_exists('visible', $data) && array_key_exists('percent_right', $data['visible'])) {
 			$percentRightCheckbox->setChecked(true);
 		}
-		elseif ($this->data['percent_right'] == 0) {
+		elseif ($data['percent_right'] == 0) {
 			$percentRightTextBox->addStyle('visibility: hidden;');
 			$percentRightCheckbox->setChecked(false);
 		}
 
-		$graphFormList->addRow(_('Percentile line (right)'), [$percentRightCheckbox, SPACE, $percentRightTextBox]);
+		$graphFormList->addRow(_('Percentile line (right)'), [$percentRightCheckbox, ' ', $percentRightTextBox]);
 	}
 
 	$yaxisMinData = [];
 	$yaxisMinData[] = (new CSelect('ymin_type'))
 		->setId('ymin_type')
-		->setValue($this->data['ymin_type'])
+		->setValue($data['ymin_type'])
 		->addOptions(CSelect::createOptionsFromArray([
 			GRAPH_YAXIS_TYPE_CALCULATED => _('Calculated'),
 			GRAPH_YAXIS_TYPE_FIXED => _('Fixed'),
 			GRAPH_YAXIS_TYPE_ITEM_VALUE => _('Item')
 		]))
-		->setDisabled($readonly);
+		->setDisabled($readonly)
+		->setFocusableElementId('ymin_type_label');
 
-	if ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_FIXED) {
+	if ($data['ymin_type'] == GRAPH_YAXIS_TYPE_FIXED) {
 		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMinData[] = (new CTextBox('yaxismin', $this->data['yaxismin'], $readonly))
+		$yaxisMinData[] = (new CTextBox('yaxismin', $data['yaxismin'], $readonly))
 			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 	}
-	elseif ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$graphForm->addVar('yaxismin', $this->data['yaxismin']);
-		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMinData[] = (new CTextBox('ymin_name', $data['ymin_item_name'], true))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAriaRequired();
+	elseif ($data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$graphForm->addVar('yaxismin', $data['yaxismin']);
+
+		$ymin_axis_ms_data = [];
+
+		if ($data['ymin_itemid'] != 0) {
+			if (array_key_exists($data['ymin_itemid'], $data['yaxis_items'])) {
+				$ymin_axis_ms_data = [[
+					'id' => $data['ymin_itemid'],
+					'name' => $data['yaxis_items'][$data['ymin_itemid']]['name'],
+					'prefix' => $data['yaxis_items'][$data['ymin_itemid']]['hosts'][0]['name'].NAME_DELIMITER
+				]];
+			}
+			else {
+				$ymin_axis_ms_data = [[
+					'id' => $data['ymin_itemid'],
+					'name' => _('Inaccessible item'),
+					'prefix' => ''
+				]];
+			}
+		}
+
 		$yaxisMinData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 
-		// Select item button.
-		$yaxisMinData[] = (new CButton('yaxis_min', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick(
-				'return PopUp("popup.generic", jQuery.extend('.json_encode([
+		$yaxisMinData[] = (new CMultiSelect([
+			'name' => 'ymin_itemid',
+			'object_name' => 'items',
+			'data' => $ymin_axis_ms_data,
+			'multiple' => false,
+			'disabled' => $readonly,
+			'styles' => [
+				'display' => 'inline-flex'
+			],
+			'popup' => [
+				'parameters' => [
 					'srctbl' => 'items',
 					'srcfld1' => 'itemid',
 					'srcfld2' => 'name',
 					'dstfrm' => $graphForm->getName(),
 					'dstfld1' => 'ymin_itemid',
-					'dstfld2' => 'ymin_name',
+					'hostid' => $data['is_template'] ? $data['hostid'] : 0,
 					'numeric' => '1',
-					'writeonly' => '1'
-				]).', view.getOnlyHostParam()), {dialogue_class: "modal-popup-generic"});'
-			)
-			->setEnabled(!$readonly);
+					'real_hosts' => !$data['is_template']
+				]
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
 		// Select item prototype button.
 		if ($data['parent_discoveryid'] !== null) {
@@ -225,7 +247,6 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 						srcfld2: "name",
 						dstfrm: "'.$graphForm->getName().'",
 						dstfld1: "ymin_itemid",
-						dstfld2: "ymin_name",
 						parent_discoveryid: this.dataset.parent_discoveryid,
 						numeric: 1
 					}, {dialogue_class: "modal-popup-generic"});
@@ -234,14 +255,12 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 		}
 	}
 	else {
-		$graphForm->addVar('yaxismin', $this->data['yaxismin']);
+		$graphForm->addVar('yaxismin', $data['yaxismin']);
 	}
 
-	$yaxismin_label = new CLabel(_('Y axis MIN value'));
-	if ($this->data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$yaxismin_label
-			->setAsteriskMark()
-			->setAttribute('for', 'ymin_name');
+	$yaxismin_label = new CLabel(_('Y axis MIN value'),'ymin_type_label');
+	if ($data['ymin_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$yaxismin_label->setAsteriskMark();
 	}
 
 	$graphFormList->addRow($yaxismin_label, $yaxisMinData);
@@ -249,43 +268,65 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 	$yaxisMaxData = [];
 	$yaxisMaxData[] = (new CSelect('ymax_type'))
 		->setId('ymax_type')
-		->setValue($this->data['ymax_type'])
+		->setValue($data['ymax_type'])
 		->addOptions(CSelect::createOptionsFromArray([
 			GRAPH_YAXIS_TYPE_CALCULATED => _('Calculated'),
 			GRAPH_YAXIS_TYPE_FIXED => _('Fixed'),
 			GRAPH_YAXIS_TYPE_ITEM_VALUE => _('Item')
 		]))
-		->setDisabled($readonly);
+		->setDisabled($readonly)
+		->setFocusableElementId('ymax_type_label');
 
-	if ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_FIXED) {
+	if ($data['ymax_type'] == GRAPH_YAXIS_TYPE_FIXED) {
 		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMaxData[] = (new CTextBox('yaxismax', $this->data['yaxismax'], $readonly))
-			->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
+		$yaxisMaxData[] = (new CTextBox('yaxismax', $data['yaxismax'], $readonly))->setWidth(ZBX_TEXTAREA_SMALL_WIDTH);
 	}
-	elseif ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$graphForm->addVar('yaxismax', $this->data['yaxismax']);
-		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
-		$yaxisMaxData[] = (new CTextBox('ymax_name', $data['ymax_item_name'], true))
-			->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
-			->setAriaRequired();
+	elseif ($data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$graphForm->addVar('yaxismax', $data['yaxismax']);
+
+		$ymax_axis_ms_data = [];
+
+		if ($data['ymax_itemid'] != 0) {
+			if (array_key_exists($data['ymax_itemid'], $data['yaxis_items'])) {
+				$ymax_axis_ms_data = [[
+					'id' => $data['ymax_itemid'],
+					'name' => $data['yaxis_items'][$data['ymax_itemid']]['name'],
+					'prefix' => $data['yaxis_items'][$data['ymax_itemid']]['hosts'][0]['name'].NAME_DELIMITER
+				]];
+			}
+			else {
+				$ymax_axis_ms_data = [[
+					'id' => $data['ymax_itemid'],
+					'name' => _('Inaccessible item'),
+					'prefix' => ''
+				]];
+			}
+		}
+
 		$yaxisMaxData[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 
-		// Select item button.
-		$yaxisMaxData[] = (new CButton('yaxis_max', _('Select')))
-			->addClass(ZBX_STYLE_BTN_GREY)
-			->onClick(
-				'return PopUp("popup.generic", jQuery.extend('.json_encode([
+		$yaxisMaxData[] = (new CMultiSelect([
+			'name' => 'ymax_itemid',
+			'object_name' => 'items',
+			'data' => $ymax_axis_ms_data,
+			'multiple' => false,
+			'disabled' => $readonly,
+			'styles' => [
+				'display' => 'inline-flex'
+			],
+			'popup' => [
+				'parameters' => [
 					'srctbl' => 'items',
 					'srcfld1' => 'itemid',
 					'srcfld2' => 'name',
 					'dstfrm' => $graphForm->getName(),
 					'dstfld1' => 'ymax_itemid',
-					'dstfld2' => 'ymax_name',
+					'hostid' => $data['is_template'] ? $data['hostid'] : 0,
 					'numeric' => '1',
-					'writeonly' => '1'
-				]).', view.getOnlyHostParam()), {dialogue_class: "modal-popup-generic"});'
-			)
-			->setEnabled(!$readonly);
+					'real_hosts' => !$data['is_template']
+				]
+			]
+		]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH);
 
 		// Select item prototype button.
 		if ($data['parent_discoveryid'] !== null) {
@@ -300,7 +341,6 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 						srcfld2: "name",
 						dstfrm: "'.$graphForm->getName().'",
 						dstfld1: "ymax_itemid",
-						dstfld2: "ymax_name",
 						parent_discoveryid: this.dataset.parent_discoveryid,
 						numeric: 1
 					}, {dialogue_class: "modal-popup-generic"});
@@ -309,14 +349,12 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 		}
 	}
 	else {
-		$graphForm->addVar('yaxismax', $this->data['yaxismax']);
+		$graphForm->addVar('yaxismax', $data['yaxismax']);
 	}
 
-	$yaxismax_label = new CLabel(_('Y axis MAX value'));
-	if ($this->data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
-		$yaxismax_label
-			->setAsteriskMark()
-			->setAttribute('for', 'ymax_name');
+	$yaxismax_label = new CLabel(_('Y axis MAX value'), 'ymax_type_label');
+	if ($data['ymax_type'] == GRAPH_YAXIS_TYPE_ITEM_VALUE) {
+		$yaxismax_label->setAsteriskMark();
 	}
 
 	$graphFormList->addRow($yaxismax_label, $yaxisMaxData);
@@ -324,7 +362,7 @@ if ($this->data['graphtype'] == GRAPH_TYPE_NORMAL || $this->data['graphtype'] ==
 else {
 	$graphFormList->addRow(_('3D view'),
 		(new CCheckBox('show_3d'))
-			->setChecked($this->data['show_3d'] == 1)
+			->setChecked($data['show_3d'] == 1)
 			->setEnabled(!$readonly)
 	);
 }
@@ -335,21 +373,21 @@ $items_table = (new CTable())
 	->setColumns([
 		(new CTableColumn())->addClass('table-col-handle'),
 		(new CTableColumn())->addClass('table-col-no'),
-		(new CTableColumn(_('Name')))->addClass(($this->data['graphtype'] == GRAPH_TYPE_NORMAL)
+		(new CTableColumn(_('Name')))->addClass(($data['graphtype'] == GRAPH_TYPE_NORMAL)
 			? 'table-col-name-normal'
 			: 'table-col-name'
 		),
-		in_array($this->data['graphtype'], [GRAPH_TYPE_PIE, GRAPH_TYPE_EXPLODED])
+		in_array($data['graphtype'], [GRAPH_TYPE_PIE, GRAPH_TYPE_EXPLODED])
 			? (new CTableColumn(_('Type')))->addClass('table-col-type')
 			: null,
 		(new CTableColumn(_('Function')))->addClass('table-col-function'),
-		($this->data['graphtype'] == GRAPH_TYPE_NORMAL)
+		($data['graphtype'] == GRAPH_TYPE_NORMAL)
 			? (new CTableColumn(
 				(new CColHeader(_('Draw style')))->addClass(ZBX_STYLE_NOWRAP)
 			))
 				->addClass('table-col-draw-style')
 			: null,
-		in_array($this->data['graphtype'], [GRAPH_TYPE_NORMAL, GRAPH_TYPE_STACKED])
+		in_array($data['graphtype'], [GRAPH_TYPE_NORMAL, GRAPH_TYPE_STACKED])
 			? (new CTableColumn(
 				(new CColHeader(_('Y axis side')))->addClass(ZBX_STYLE_NOWRAP)
 			))
@@ -436,9 +474,12 @@ if ($data['parent_discoveryid']) {
 
 // Append tabs to form.
 $graphTab = (new CTabView())
-	->setSelected(0)
 	->addTab('graphTab', ($data['parent_discoveryid'] === null) ? _('Graph') : _('Graph prototype'), $graphFormList);
 
+if (!$data['form_refresh']) {
+	$graphTab->setSelected(0);
+}
+
 /*
  * Preview tab
  */
