@@ -24,7 +24,9 @@
  * @var array $data
  */
 
-$widget = (new CWidget())->setTitle(_('Item prototypes'));
+$widget = (new CWidget())
+	->setTitle(_('Item prototypes'))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::CONFIGURATION_ITEM_PROTOTYPE_EDIT));
 
 if (!empty($data['hostid'])) {
 	$widget->setNavigation(getHostNavigation('items', $data['hostid'], $data['parent_discoveryid']));
@@ -546,36 +548,40 @@ if (!$readonly) {
 	$master_item[] = (new CButton('button', _('Select')))
 		->addClass(ZBX_STYLE_BTN_GREY)
 		->removeId()
-		->onClick(
-			'return PopUp("popup.generic", '.json_encode([
-				'srctbl' => 'items',
-				'srcfld1' => 'itemid',
-				'srcfld2' => 'name',
-				'dstfrm' => $form->getName(),
-				'dstfld1' => 'master_itemid',
-				'dstfld2' => 'master_itemname',
-				'only_hostid' => $data['hostid'],
-				'excludeids' => [$data['itemid']],
-				'with_webitems' => 1,
-				'normal_only' => 1
-			]).', {dialogue_class: "modal-popup-generic"});'
-		);
+		->setAttribute('data-hostid', $data['hostid'])
+		->setAttribute('data-itemid', $data['itemid'])
+		->onClick('
+			PopUp("popup.generic", {
+				srctbl: "items",
+				srcfld1: "itemid",
+				srcfld2: "name",
+				dstfrm: "'.$form->getName().'",
+				dstfld1: "master_itemid",
+				dstfld2: "master_itemname",
+				only_hostid: this.dataset.hostid,
+				excludeids: [this.dataset.itemid],
+				normal_only: 1
+			}, {dialogue_class: "modal-popup-generic"});
+		');
+
 	$master_item[] = (new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN);
 	$master_item[] = (new CButton('button', _('Select prototype')))
 		->addClass(ZBX_STYLE_BTN_GREY)
 		->removeId()
-		->onClick(
-			'return PopUp("popup.generic", '.json_encode([
-				'srctbl' => 'item_prototypes',
-				'srcfld1' => 'itemid',
-				'srcfld2' => 'name',
-				'dstfrm' => $form->getName(),
-				'dstfld1' => 'master_itemid',
-				'dstfld2' => 'master_itemname',
-				'parent_discoveryid' => $data['parent_discoveryid'],
-				'excludeids' => [$data['itemid']]
-			]).', {dialogue_class: "modal-popup-generic"});'
-		);
+		->setAttribute('data-discoveryid', $data['parent_discoveryid'])
+		->setAttribute('data-itemid', $data['itemid'])
+		->onClick('
+			PopUp("popup.generic", {
+				srctbl: "item_prototypes",
+				srcfld1: "itemid",
+				srcfld2: "name",
+				dstfrm: "'.$form->getName().'",
+				dstfld1: "master_itemid",
+				dstfld2: "master_itemname",
+				parent_discoveryid: this.dataset.discoveryid,
+				excludeids: [this.dataset.itemid]
+			}, {dialogue_class: "modal-popup-generic"});
+		');
 }
 
 $item_tab->addItem([
@@ -585,15 +591,15 @@ $item_tab->addItem([
 	(new CFormField($master_item))->setId('js-item-master-item-field')
 ]);
 
-// Append interfaces to form list.
-$select_interface = getInterfaceSelect($data['interfaces'])
-	->setId('interface-select')
-	->setValue($data['interfaceid'])
-	->addClass(ZBX_STYLE_ZSELECT_HOST_INTERFACE)
-	->setFocusableElementId('interfaceid')
-	->setAriaRequired();
-
 if ($data['display_interfaces']) {
+	$select_interface = getInterfaceSelect($data['interfaces'])
+		->setId('interface-select')
+		->setValue($data['interfaceid'])
+		->addClass(ZBX_STYLE_ZSELECT_HOST_INTERFACE)
+		->setFocusableElementId('interfaceid')
+		->setAriaRequired()
+		->setReadonly($readonly);
+
 	$item_tab->addItem([
 		(new CLabel(_('Host interface'), $select_interface->getFocusableElementId()))
 			->setAsteriskMark()
