@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,9 @@
 
 require_once dirname(__FILE__).'/js/configuration.maintenance.edit.js.php';
 
-$widget = (new CWidget())->setTitle(_('Maintenance periods'));
+$widget = (new CWidget())
+	->setTitle(_('Maintenance periods'))
+	->setDocUrl(CDocHelper::getUrl(CDocHelper::CONFIGURATION_MAINTENANCE_EDIT));
 
 $maintenance_form = (new CForm())
 	->setId('maintenance-form')
