@@ -23,6 +23,8 @@
  * @var CView $this
  */
 
+$this->includeJsFile('inventory.host.view.js.php');
+
 // Overview tab.
 $overviewFormList = new CFormList();
 
@@ -71,7 +73,7 @@ foreach ($data['host']['interfaces'] as $interface) {
 
 $header_is_set = false;
 
-foreach ([INTERFACE_TYPE_AGENT, INTERFACE_TYPE_SNMP, INTERFACE_TYPE_JMX, INTERFACE_TYPE_IPMI] as $type) {
+foreach (CItem::INTERFACE_TYPES_BY_PRIORITY as $type) {
 	if ($interfaces[$type]) {
 		$ifTab = (new CTable());
 
@@ -142,9 +144,9 @@ $overviewFormList->addRow(_('Monitoring'),
 		$data['allowed_ui_latest_data']
 			? new CLink(_('Latest data'), (new CUrl('zabbix.php'))
 				->setArgument('action', 'latest.view')
-				->setArgument('filter_hostids[]', $data['host']['hostid'])
-				->setArgument('filter_show_details', '1')
-				->setArgument('filter_set', '1')
+				->setArgument('hostids[]', $data['host']['hostid'])
+				->setArgument('show_details', '1')
+				->setArgument('filter_name', '')
 			)
 			: _('Latest data'),
 		$data['allowed_ui_problems']
@@ -158,11 +160,9 @@ $overviewFormList->addRow(_('Monitoring'),
 			? new CLink(_('Graphs'),
 				(new CUrl('zabbix.php'))
 					->setArgument('action', 'charts.view')
-					->setArgument('filter_set', '1')
-					->setArgument('view_as', HISTORY_GRAPH)
-					->setArgument('filter_search_type', ZBX_SEARCH_TYPE_STRICT)
 					->setArgument('filter_hostids', [$data['host']['hostid']])
-			)
+					->setArgument('filter_set', '1')
+		)
 			: _('Graphs'),
 		$data['allowed_ui_hosts']
 			? new CLink(_('Dashboards'), (new CUrl('zabbix.php'))
@@ -175,10 +175,9 @@ $overviewFormList->addRow(_('Monitoring'),
 
 // configuration
 if ($data['allowed_ui_conf_hosts'] && $data['rwHost']) {
-	$hostLink = new CLink(_('Host'), (new CUrl('hosts.php'))
-		->setArgument('form', 'update')
-		->setArgument('hostid', $data['host']['hostid'])
-	);
+	$hostLink = (new CLink(_('Host')))
+		->setAttribute('data-hostid', $data['host']['hostid'])
+		->onClick('view.editHost({hostid: this.dataset.hostid});');
 	$itemsLink = new CLink(_('Items'),
 		(new CUrl('items.php'))
 			->setArgument('filter_set', '1')
