@@ -151,11 +151,15 @@ jQuery(function($) {
 				break;
 
 			case 'item':
-				sections = getMenuPopupItem(data, $obj);
+				sections = getMenuPopupItem(data);
 				break;
 
-			case 'item_prototype':
-				sections = getMenuPopupItemPrototype(data);
+			case 'item_configuration':
+				sections = getMenuPopupItemConfiguration(data);
+				break;
+
+			case 'item_prototype_configuration':
+				sections = getMenuPopupItemPrototypeConfiguration(data);
 				break;
 
 			case 'dropdown':
@@ -166,10 +170,6 @@ jQuery(function($) {
 				sections = getMenuPopupSubmenu(data);
 				break;
 
-			case 'widget_actions':
-				sections = getMenuPopupWidgetActions(data);
-				break;
-
 			default:
 				return;
 		}
@@ -314,6 +314,17 @@ jQuery(function($) {
 
 			xhr.done(function(resp) {
 				overlayPreloaderDestroy($preloader.prop('id'));
+
+				if ('error' in resp) {
+					clearMessages();
+
+					const message_box = makeMessageBox('bad', resp.error.messages, resp.error.title);
+
+					addMessage(message_box);
+
+					return;
+				}
+
 				showMenuPopup($obj, jQuery.extend({context: data.context}, resp.data), event, options);
 			});
 
@@ -364,6 +375,9 @@ jQuery(function($) {
 			// execute function if they exist
 			window.addPopupValues(data);
 		}
+		else if (typeof view.addPopupValues !== 'undefined') {
+			view.addPopupValues(data);
+		}
 		else {
 			$('#' + data.parentId).val(data.values[0].name);
 		}
