@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -32,15 +32,28 @@ jQuery(function($) {
 			});
 		});
 
-		if ($layout_mode_btn.hasClass('btn-dashbrd-normal')) {
-			$(window).on('mousemove keyup scroll', function() {
-				clearTimeout($layout_mode_btn.data('timer'));
-				$layout_mode_btn
-					.removeClass('hidden')
-					.data('timer', setTimeout(function() {
-						$layout_mode_btn.addClass('hidden');
-					}, 2000));
-			}).trigger('mousemove');
+		const header_kioskmode_controls = document.querySelector('.header-kioskmode-controls');
+
+		if (header_kioskmode_controls !== null) {
+			let timeout_id = null;
+
+			const show_header_kioskmode_controls = () => {
+				if (timeout_id !== null) {
+					clearTimeout(timeout_id);
+				}
+
+				header_kioskmode_controls.classList.remove('hidden');
+
+				timeout_id = setTimeout(() => {
+					header_kioskmode_controls.classList.add('hidden');
+				}, 2000);
+			};
+
+			for (const event_name of ['mousemove', 'mousedown', 'keydown', 'wheel']) {
+				window.addEventListener(event_name, show_header_kioskmode_controls);
+			}
+
+			show_header_kioskmode_controls();
 		}
 	}
 });
